@@ -43,7 +43,7 @@ class SchedulerClient:
         async def callOnEnd(job):
             runId = job['executor']['id']
             strategyRepository = await self.root.strategyRepository()
-            runResult = await strategyRepository.findOneStrategyRunResult(runId)
+            runResult = await strategyRepository.findOneStrategyResult(runId)
             onEnd(runResult)
 
         sub = await self.onJobFinished(
