@@ -9,10 +9,10 @@ class StrategyRepositoryClient:
         self.root = root
         self.service = service
 
-    async def findOneStrategyRunResult(self, runId:str):
-        # print('findOneStrategyRunResult', 'runId:', runId)
+    async def findOneStrategyResult(self, runId:str):
+        # print('findOneStrategyResult', 'runId:', runId)
 
-        res = await self.service.query(QUERIES['FIND_ONE_STRATEGY_RUN_RESULT'], {
+        res = await self.service.query(QUERIES['FIND_ONE_STRATEGY_RESULT'], {
             'runId': runId
         })
 
