@@ -30,11 +30,11 @@ QUERIES = {
         }
         ''',
 
-    'FIND_ONE_STRATEGY_RUN_RESULT':
+    'FIND_ONE_STRATEGY_RESULT':
         '''
         query ($runId: String!){
-            findOneStrategyRunResult(runId: $runId) {
-                statistics
+            findOneStrategyResult(runId: $runId) {
+                strategyStats
                 monteCarlo
             }
         }
